summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/umlviewimageexportermodel.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60 (patch)
treebabc4a761925023e16fa94633959f35d1c251887 /umbrello/umbrello/umlviewimageexportermodel.cpp
parent0813b39aed2cf4c84157a22c4c9594336d93d412 (diff)
downloadtdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.tar.gz
tdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/umlviewimageexportermodel.cpp')
-rw-r--r--umbrello/umbrello/umlviewimageexportermodel.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/umbrello/umbrello/umlviewimageexportermodel.cpp b/umbrello/umbrello/umlviewimageexportermodel.cpp
index 0fab653a..a8de3637 100644
--- a/umbrello/umbrello/umlviewimageexportermodel.cpp
+++ b/umbrello/umbrello/umlviewimageexportermodel.cpp
@@ -174,14 +174,14 @@ TQString UMLViewImageExporterModel::getDiagramFileName(UMLView *view, const TQSt
UMLListView *listView = UMLApp::app()->getListView();
UMLListViewItem* listViewItem = listView->findItem(view->getID());
// skip the name of the first item because it's the View
- listViewItem = static_cast<UMLListViewItem*>(listViewItem->tqparent());
+ listViewItem = static_cast<UMLListViewItem*>(listViewItem->parent());
// Relies on the tree structure of the UMLListView. There are a base "Views" folder
// and five tqchildren, one for each view type (Logical, use case, components, deployment
// and entity relationship)
while (listView->rootView(listViewItem->getType()) == NULL) {
name.insert(0, listViewItem->getText() + '/');
- listViewItem = static_cast<UMLListViewItem*>(listViewItem->tqparent());
+ listViewItem = static_cast<UMLListViewItem*>(listViewItem->parent());
if (listViewItem == NULL)
break;
}
@@ -193,7 +193,7 @@ bool UMLViewImageExporterModel::prepareDirectory(const KURL &url) const {
KURL directory = url;
directory.setPath("");
// creates the directory and any needed tqparent directories
TQStringList dirs = TQStringList::split(TQDir::separator(), url.directory());
for (TQStringList::ConstIterator it = dirs.begin() ; it != dirs.end(); ++it ) {
directory.addPath(*it);
@@ -193,7 +193,7 @@ bool UMLViewImageExporterModel::prepareDirectory(const KURL &url) const {
KURL directory = url;
directory.setPath("");
- // creates the directory and any needed tqparent directories
+ // creates the directory and any needed parent directories
TQStringList dirs = TQStringList::split(TQDir::separator(), url.directory());
for (TQStringList::ConstIterator it = dirs.begin() ; it != dirs.end(); ++it ) {